%bcond_without  lib

%define major 3
%define libname %mklibname %{name} %{major}
%define develname %mklibname -d %{name}
%define sdevelname %mklibname -d -s %{name}
%define cvsver 3_113
%define version 3.113.0

%define patchver %(echo %{version}|cut -d. -f3)
%if %{?patchver}
%define tarballver %{version}
%else
%define tarballver %(echo %{version}|cut -d. -f1,2)
%endif

%define nspr_libname %mklibname nspr 4

# this seems fragile, so require the exact version or later (#58754)
%define sqlite3_version %(pkg-config --modversion sqlite3 &>/dev/null && pkg-config --modversion sqlite3 2>/dev/null || echo 0)
%define nspr_version %(pkg-config --modversion nspr &>/dev/null && pkg-config --modversion nspr 2>/dev/null || echo 0)

Name:		nss
Epoch:		2
Version:	%{version}
%define subrel	1
Release:	%mkrel 1
Summary:	Network Security Services
Group:		System/Libraries
License:	MPLv1.1 or GPLv2+ or LGPLv2+
URL:		https://www.mozilla.org/projects/security/pki/nss/index.html
Source0:	https://ftp.mozilla.org/pub/security/nss/releases/NSS_%{cvsver}_RTM/src/nss-%{tarballver}.tar.gz
# Numbered as in Fedora:
Source8:	nss.pc.in
Source9:	nss-config.in
Source10:	blank-cert8.db
Source11:	blank-key3.db
Source12:	blank-secmod.db
Source28:	nss-p11-kit.config
Patch0:		nss-no-rpath.patch
Patch4:		renegotiate-transitional.patch
Patch20:	nss-gcm-param-default-pkcs11v2.patch
%if %with lib
Requires:	crypto-policies
%endif
BuildRequires:	nspr-devel >= 2:4.36
BuildRequires:	pkgconfig(zlib)
# one should look in nss/lib/sqlite/README to check which version is "recommended"
BuildRequires:	pkgconfig(sqlite3) >= 3.7.17
Provides:	nss-tools = %{version}-%{release}

%description
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled client and server
applications. Applications built with NSS can support SSL v2 and v3,
TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509 v3 certificates, and
other security standards. For detailed information on standards supported, see
https://www.mozilla.org/projects/security/pki/nss/overview.html.
%if %without lib

Note: This package currently contains the NSS binaries only. The
libraries have been not been included due to conflicts with the Mozilla
libraries.
%endif

%package doc
Summary:	Network Security Services (NSS) - Documentation
Group:		Documentation
BuildArch:	noarch

%description doc
Documentation for Network Security Services.

%if %with lib
%package -n %{libname}
Summary:	Network Security Services (NSS)
Group:		System/Libraries
Provides:	mozilla-nss = %{epoch}:%{version}-%{release}
Requires(pre):	filesystem >= 2.1.9-18
Requires(post):	nss
Requires(post):	rpm-helper
Requires:	%{mklibname sqlite3_ 0} >= %{sqlite3_version}
Requires:	%{nspr_libname} >= 2:%{nspr_version}
Requires:	p11-kit-trust
Conflicts:	%{_lib}nss-devel < 2:3.13.5-2

%description -n %{libname}
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled server
applications. Applications built with NSS can support SSL v2 and v3,
TLS, PKCS #5, PKCS #7, PKCS #11, PKCS
#12, S/MIME, X.509 v3 certificates, and other security standards. For
detailed information on standards supported, see
https://www.mozilla.org/projects/security/pki/nss/overview.html.

%package -n %{develname}
Summary:	Development libraries for Network Security Services
Group:		Development/C++
Requires(pre):	filesystem >= 2.1.9-18
Requires:	%{libname} = %{epoch}:%{version}-%{release}
Requires:	libnspr-devel
BuildRequires:	xmlto-notex
Provides:	libnss-devel = %{epoch}:%{version}-%{release}
Provides:	nss-devel = %{epoch}:%{version}-%{release}
# (cg) The -devel package doesn't generate these automatically.
%ifarch x86_64 aarch64
Provides: devel(libfreebl3(64bit))
Provides: devel(libnss3(64bit))
Provides: devel(libnssdbm3(64bit))
Provides: devel(libnssutil3(64bit))
Provides: devel(libsmime3(64bit))
Provides: devel(libsoftokn3(64bit))
Provides: devel(libssl3(64bit))
%else
Provides: devel(libfreebl3)
Provides: devel(libnss3)
Provides: devel(libnssdbm3)
Provides: devel(libnssutil3)
Provides: devel(libsmime3)
Provides: devel(libsoftokn3)
Provides: devel(libssl3)
%endif
Obsoletes:	%{libname}-devel < 2:3.12-8
Conflicts:	%{libname} < 2:3.12-8

%description -n %{develname}
Header files to doing development with Network Security Services.

%package -n %{sdevelname}
Summary:	Network Security Services (NSS) - static libraries
Group:		Development/C++
Requires:	%{libname} = %{epoch}:%{version}-%{release}
Requires:	%{develname} = %{epoch}:%{version}-%{release}
Requires:	libnspr-devel >= 2:%{nspr_version} 
Provides:	libnss-static-devel = %{epoch}:%{version}-%{release}
Provides:	nss-static-devel = %{epoch}:%{version}-%{release}
Conflicts:	libopenssl-static-devel
Obsoletes:	%{libname}-static-devel < 2:3.12-8

%description -n %{sdevelname}
Static libraries for doing development with Network Security Services.
%endif

%prep
%setup -qn %{name}-%{tarballver}
%autopatch -p0

# https://bugzilla.redhat.com/show_bug.cgi?id=1247353
find nss/lib/libpkix -perm /u+x -type f -exec chmod -x {} \;


%build
%set_build_flags
# Enable compiler optimizations and disable debugging code
export BUILD_OPT=1
export OPTIMIZER="%{optflags}"
export XCFLAGS="%{optflags}"
export LDOPTS="$LDFLAGS"
export ARCHFLAG="$LDFLAGS"
export LIBDIR=%{_libdir}
export USE_SYSTEM_ZLIB=1
export ZLIB_LIBS="-lz"
export PKG_CONFIG_ALLOW_SYSTEM_LIBS=1
export PKG_CONFIG_ALLOW_SYSTEM_CFLAGS=1

export NSPR_INCLUDE_DIR=`/usr/bin/pkg-config --cflags-only-I nspr | sed 's/-I//'`
export NSPR_LIB_DIR=%{_libdir}
export MOZILLA_CLIENT=1
export NS_USE_GCC=1
export NSS_USE_SYSTEM_SQLITE=1
export NSS_ENABLE_ECC=1
export NSS_ALLOW_SSLKEYLOGFILE=1
export NSS_SEED_ONLY_DEV_URANDOM=1
%ifnarch noarch
%if 0%{__isa_bits} == 64
export USE_64=1
%endif
%endif

%make_build -j1 -C ./nss all
%make_build -C ./nss latest

OLD="$LD_LIBRARY_PATH"
libpath=`%{_bindir}/find ./dist/ -name "Linux*.*" -type d`
# to use the built libraries instead of requiring nss
# again as buildrequires
export LD_LIBRARY_PATH="$PWD/$libpath/lib"

pushd nss/lib/ckfw/builtins

%make_build clean
%make_build -j1

popd
export LD_LIBRARY_PATH="$OLD"

# build the man pages clean
pushd ./nss
%{__make} clean_docs build_docs
popd

# and copy them to the dist directory for %%install to find them
mkdir -p ./dist/docs/nroff
cp ./nss/doc/nroff/* ./dist/docs/nroff

%install
# There is no make install target so we'll do it ourselves.

pushd dist/$(uname -s)*

mkdir -p %{buildroot}%{_bindir}
cp -aL bin/* %{buildroot}%{_bindir}

%if %with lib
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}/nss
cp -aL ../public/nss/* %{buildroot}%{_includedir}/nss

cp -aL lib/libcrmf.a \
            lib/libnss.a \
            lib/libnssb.a \
            lib/libnssckfw.a \
	    lib/libnssutil.a \
            lib/libsmime.a \
            lib/libssl.a \
            %{buildroot}%{_libdir}

# Copy the binary libraries we want
for file in libsoftokn3.so libfreebl3.so libfreeblpriv3.so libnss3.so \
    libnssutil3.so libssl3.so libsmime3.so libnssdbm3.so
do
  install -m 755 lib/$file %{buildroot}%{_libdir}
done

ln -s %{_libdir}/pkcs11/p11-kit-trust.so %{buildroot}%{_libdir}/libnssckbi.so

# These ghost files will be generated in the post step
# Make sure chk files can be found in both places
for file in libsoftokn3.chk libfreebl3.chk libfreeblpriv3.chk
do
  touch %{buildroot}%{_libdir}/$file
done

mkdir -p %{buildroot}%{_libdir}/pkgconfig
cat %{SOURCE8} | sed -e "s,%%libdir%%,%{_libdir},g" \
                          -e "s,%%prefix%%,%{_prefix},g" \
                          -e "s,%%exec_prefix%%,%{_prefix},g" \
                          -e "s,%%includedir%%,%{_includedir}/nss,g" \
                          -e "s,%%NSS_VERSION%%,%{version},g" \
                          -e "s,%%NSPR_VERSION%%,%{nspr_version},g" \
			  > \
                          %{buildroot}%{_libdir}/pkgconfig/nss.pc

mkdir -p %{buildroot}%{_sysconfdir}/crypto-policies/local.d
install -p -m 644 %{SOURCE28} %{buildroot}%{_sysconfdir}/crypto-policies/local.d

%endif

popd

%if %with lib
NSS_VMAJOR=`cat nss/lib/nss/nss.h | grep "#define.*NSS_VMAJOR" | awk '{print $3}'`
NSS_VMINOR=`cat nss/lib/nss/nss.h | grep "#define.*NSS_VMINOR" | awk '{print $3}'`
NSS_VPATCH=`cat nss/lib/nss/nss.h | grep "#define.*NSS_VPATCH" | awk '{print $3}'`

mkdir -p %{buildroot}%{_bindir}
cat %{SOURCE9} | sed -e "s,@libdir@,%{_libdir},g" \
                               -e "s,@prefix@,%{_prefix},g" \
                               -e "s,@exec_prefix@,%{_prefix},g" \
                               -e "s,@includedir@,%{_includedir}/nss%{major},g" \
                               -e "s,@MOD_MAJOR_VERSION@,$NSS_VMAJOR,g" \
                               -e "s,@MOD_MINOR_VERSION@,$NSS_VMINOR,g" \
                               -e "s,@MOD_PATCH_VERSION@,$NSS_VPATCH,g" \
                               > %{buildroot}/%{_bindir}/nss-config
%endif

pushd nss/cmd/smimetools
install -m 0755 smime %{buildroot}%{_bindir}
perl -pi -e 's|/usr/local/bin|%{_bindir}|g' %{buildroot}%{_bindir}/smime
popd

# add docs
mkdir -p docs/SSLsample
#%cp -a nss/cmd/SSLsample/README docs/SSLsample/

mkdir -p docs/bltest
cp -a nss/cmd/bltest/tests/* docs/bltest/

mkdir -p docs/modutil
cp -a nss/cmd/modutil/*.html docs/modutil/

mkdir -p docs/signtool
cp -a nss/cmd/signtool/README docs/signtool/

mkdir -p docs/signver
cp -a nss/cmd/signver/examples/1/*.pl docs/signver/
cp -a nss/cmd/signver/examples/1/*.html docs/signver/

mkdir -p docs/ssltap
cp -a nss/cmd/ssltap/*.html docs/ssltap/

# Copy the man pages for the nss tools
mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 ./dist/docs/nroff/*.1 %{buildroot}%{_mandir}/man1

# Install the empty NSS db files
# Legacy db
mkdir -p %{buildroot}%{_sysconfdir}/pki/nssdb
install -p -m 644 %{SOURCE10} %{buildroot}%{_sysconfdir}/pki/nssdb/cert8.db
install -p -m 644 %{SOURCE11} %{buildroot}%{_sysconfdir}/pki/nssdb/key3.db
install -p -m 644 %{SOURCE12} %{buildroot}%{_sysconfdir}/pki/nssdb/secmod.db

%{_bindir}/find docs -type f | %{_bindir}/xargs -t perl -pi -e 's/\r$//g'

%multiarch_binaries %{buildroot}%{_bindir}/nss-config

%if %with lib
%posttrans
update-crypto-policies &> /dev/null || :

%post -n %{libname}
%create_ghostfile %{_libdir}/libsoftokn%{major}.chk root root 644
%create_ghostfile %{_libdir}/libfreebl%{major}.chk root root 644
%create_ghostfile %{_libdir}/libfreeblpriv%{major}.chk root root 644
%{_bindir}/shlibsign -i %{_libdir}/libsoftokn%{major}.so >/dev/null 2>/dev/null
%{_bindir}/shlibsign -i %{_libdir}/libfreebl%{major}.so >/dev/null 2>/dev/null
%{_bindir}/shlibsign -i %{_libdir}/libfreeblpriv%{major}.so >/dev/null 2>/dev/null
%endif

%files
%attr(0755,root,root) %{_bindir}/addbuiltin
%attr(0755,root,root) %{_bindir}/atob
%attr(0755,root,root) %{_bindir}/baddbdir
%attr(0755,root,root) %{_bindir}/base_gtest
%attr(0755,root,root) %{_bindir}/bltest
%attr(0755,root,root) %{_bindir}/btoa
%attr(0755,root,root) %{_bindir}/certdb_gtest
%attr(0755,root,root) %{_bindir}/certhigh_gtest
%attr(0755,root,root) %{_bindir}/certutil
%attr(0755,root,root) %{_bindir}/chktest
%attr(0755,root,root) %{_bindir}/cmsutil
%attr(0755,root,root) %{_bindir}/conflict
%attr(0755,root,root) %{_bindir}/crlutil
%attr(0755,root,root) %{_bindir}/crmftest
%attr(0755,root,root) %{_bindir}/cryptohi_gtest
%attr(0755,root,root) %{_bindir}/dbtest
%attr(0755,root,root) %{_bindir}/dbtool
%attr(0755,root,root) %{_bindir}/der_gtest
%attr(0755,root,root) %{_bindir}/derdump
%attr(0755,root,root) %{_bindir}/dertimetest
%attr(0755,root,root) %{_bindir}/digest
%attr(0755,root,root) %{_bindir}/ecperf
%attr(0755,root,root) %{_bindir}/encodeinttest
%attr(0755,root,root) %{_bindir}/fbectest
%attr(0755,root,root) %{_bindir}/fipstest
%attr(0755,root,root) %{_bindir}/freebl_gtest
%attr(0755,root,root) %{_bindir}/httpserv
%attr(0755,root,root) %{_bindir}/listsuites
%attr(0755,root,root) %{_bindir}/lowhashtest
%attr(0755,root,root) %{_bindir}/makepqg
%attr(0755,root,root) %{_bindir}/mangle
%attr(0755,root,root) %{_bindir}/modutil
%attr(0755,root,root) %{_bindir}/multinit
%attr(0755,root,root) %{_bindir}/nonspr10
%attr(0755,root,root) %{_bindir}/nss_bogo_shim
%attr(0755,root,root) %{_bindir}/nss-policy-check
%attr(0755,root,root) %{_bindir}/nssdefaults
%attr(0755,root,root) %{_bindir}/ocspclnt
%attr(0755,root,root) %{_bindir}/ocspresp
%attr(0755,root,root) %{_bindir}/oidcalc
%attr(0755,root,root) %{_bindir}/p7content
%attr(0755,root,root) %{_bindir}/p7env
%attr(0755,root,root) %{_bindir}/p7sign
%attr(0755,root,root) %{_bindir}/p7verify
%attr(0755,root,root) %{_bindir}/pk11ectest
%attr(0755,root,root) %{_bindir}/pk11gcmtest
%attr(0755,root,root) %{_bindir}/pk11importtest
%attr(0755,root,root) %{_bindir}/pk11mode
%attr(0755,root,root) %{_bindir}/pk11_gtest
%attr(0755,root,root) %{_bindir}/pk12util
%attr(0755,root,root) %{_bindir}/pk1sign
%attr(0755,root,root) %{_bindir}/pkix-errcodes
%attr(0755,root,root) %{_bindir}/pp
%attr(0755,root,root) %{_bindir}/pwdecrypt
%attr(0755,root,root) %{_bindir}/remtest
%attr(0755,root,root) %{_bindir}/rsaperf
%attr(0755,root,root) %{_bindir}/rsapoptst
%attr(0755,root,root) %{_bindir}/sdbthreadtst
%attr(0755,root,root) %{_bindir}/sdrtest
%attr(0755,root,root) %{_bindir}/secmodtest
%attr(0755,root,root) %{_bindir}/selfserv
%attr(0755,root,root) %{_bindir}/shlibsign
%attr(0755,root,root) %{_bindir}/signtool
%attr(0755,root,root) %{_bindir}/signver
%attr(0755,root,root) %{_bindir}/smime
%attr(0755,root,root) %{_bindir}/smime_gtest
%attr(0755,root,root) %{_bindir}/softoken_gtest
%attr(0755,root,root) %{_bindir}/ssl_gtest
%attr(0755,root,root) %{_bindir}/ssltap
%attr(0755,root,root) %{_bindir}/strsclnt
%attr(0755,root,root) %{_bindir}/symkeyutil
%attr(0755,root,root) %{_bindir}/tstclnt
%attr(0755,root,root) %{_bindir}/util_gtest
%attr(0755,root,root) %{_bindir}/validation
%attr(0755,root,root) %{_bindir}/vfychain
%attr(0755,root,root) %{_bindir}/vfyserv
%{_mandir}/man1/*
%dir %{_sysconfdir}/pki/nssdb
%config(noreplace) %{_sysconfdir}/pki/nssdb/cert8.db
%config(noreplace) %{_sysconfdir}/pki/nssdb/key3.db
%config(noreplace) %{_sysconfdir}/pki/nssdb/secmod.db
%if %with lib
%config(noreplace) %{_sysconfdir}/crypto-policies/local.d/nss-p11-kit.config
%endif

%files doc
%doc docs/*

%if %with lib
%files -n %{libname}
%{_libdir}/libfreebl%{major}.so
%{_libdir}/libfreeblpriv%{major}.so
%{_libdir}/libnss%{major}.so
%{_libdir}/libnssckbi.so
%{_libdir}/libsmime%{major}.so
%{_libdir}/libsoftokn%{major}.so
%{_libdir}/libssl%{major}.so
%{_libdir}/libnssutil%{major}.so
%{_libdir}/libnssdbm%{major}.so
%ghost %{_libdir}/libsoftokn%{major}.chk
%ghost %{_libdir}/libfreebl%{major}.chk
%ghost %{_libdir}/libfreeblpriv%{major}.chk

%files -n %{develname}
%{_bindir}/nss-config
%attr(0755,root,root) %{multiarch_bindir}/nss-config
%dir %{_includedir}/nss
%{_includedir}/nss/base64.h
%{_includedir}/nss/blapit.h
%{_includedir}/nss/certdb.h
%{_includedir}/nss/cert.h
%{_includedir}/nss/certt.h
%{_includedir}/nss/ciferfam.h
%{_includedir}/nss/cmmf.h
%{_includedir}/nss/cmmft.h
%{_includedir}/nss/cms.h
%{_includedir}/nss/cmsreclist.h
%{_includedir}/nss/cmst.h
%{_includedir}/nss/crmf.h
%{_includedir}/nss/crmft.h
%{_includedir}/nss/cryptohi.h
%{_includedir}/nss/cryptoht.h
%{_includedir}/nss/eccutil.h
%{_includedir}/nss/ecl-exp.h
%{_includedir}/nss/hasht.h
%{_includedir}/nss/jar-ds.h
%{_includedir}/nss/jarfile.h
%{_includedir}/nss/jar.h
%{_includedir}/nss/key.h
%{_includedir}/nss/keyhi.h
%{_includedir}/nss/keyt.h
%{_includedir}/nss/keythi.h
%{_includedir}/nss/kyber.h
%{_includedir}/nss/lowkeyi.h
%{_includedir}/nss/lowkeyti.h
%{_includedir}/nss/nssb64.h
%{_includedir}/nss/nssb64t.h
%{_includedir}/nss/nssbase.h
%{_includedir}/nss/nssbaset.h
%{_includedir}/nss/nssck.api
%{_includedir}/nss/nssckbi.h
%{_includedir}/nss/nssckepv.h
%{_includedir}/nss/nssckft.h
%{_includedir}/nss/nssckfwc.h
%{_includedir}/nss/nssckfw.h
%{_includedir}/nss/nssckfwt.h
%{_includedir}/nss/nssckg.h
%{_includedir}/nss/nssckmdt.h
%{_includedir}/nss/nssckt.h
%{_includedir}/nss/nss.h
%{_includedir}/nss/nsshash.h
%{_includedir}/nss/nssilckt.h
%{_includedir}/nss/nssilock.h
%{_includedir}/nss/nsslocks.h
%{_includedir}/nss/nsslowhash.h
%{_includedir}/nss/nssrwlk.h
%{_includedir}/nss/nssrwlkt.h
%{_includedir}/nss/nssutil.h
%{_includedir}/nss/ocsp.h
%{_includedir}/nss/ocspt.h
%{_includedir}/nss/p12.h
%{_includedir}/nss/p12plcy.h
%{_includedir}/nss/p12t.h
%{_includedir}/nss/pk11func.h
%{_includedir}/nss/pk11hpke.h
%{_includedir}/nss/pk11pqg.h
%{_includedir}/nss/pk11priv.h
%{_includedir}/nss/pk11pub.h
%{_includedir}/nss/pk11sdr.h
%{_includedir}/nss/pkcs11f.h
%{_includedir}/nss/pkcs11.h
%{_includedir}/nss/pkcs11n.h
%{_includedir}/nss/pkcs11p.h
%{_includedir}/nss/pkcs11t.h
%{_includedir}/nss/pkcs11u.h
%{_includedir}/nss/pkcs11uri.h
%{_includedir}/nss/pkcs12.h
%{_includedir}/nss/pkcs12t.h
%{_includedir}/nss/pkcs1sig.h
%{_includedir}/nss/pkcs7t.h
%{_includedir}/nss/portreg.h
%{_includedir}/nss/preenc.h
%{_includedir}/nss/secasn1.h
%{_includedir}/nss/secasn1t.h
%{_includedir}/nss/seccomon.h
%{_includedir}/nss/secder.h
%{_includedir}/nss/secdert.h
%{_includedir}/nss/secdig.h
%{_includedir}/nss/secdigt.h
%{_includedir}/nss/secerr.h
%{_includedir}/nss/sechash.h
%{_includedir}/nss/secitem.h
%{_includedir}/nss/secmime.h
%{_includedir}/nss/secmod.h
%{_includedir}/nss/secmodt.h
%{_includedir}/nss/secoid.h
%{_includedir}/nss/secoidt.h
%{_includedir}/nss/secpkcs5.h
%{_includedir}/nss/secpkcs7.h
%{_includedir}/nss/secport.h
%{_includedir}/nss/shsign.h
%{_includedir}/nss/smime.h
%{_includedir}/nss/sslerr.h
%{_includedir}/nss/sslexp.h
%{_includedir}/nss/ssl.h
%{_includedir}/nss/sslproto.h
%{_includedir}/nss/sslt.h
%{_includedir}/nss/utilmodt.h
%{_includedir}/nss/utilpars.h
%{_includedir}/nss/utilparst.h
%{_includedir}/nss/utilrename.h
%{_libdir}/pkgconfig/nss.pc
%{_libdir}/libsoftokn%{major}.chk
%{_libdir}/libfreebl%{major}.chk
%{_libdir}/libfreeblpriv%{major}.chk

%files -n %{sdevelname}
%{_libdir}/libcrmf.a
%{_libdir}/libnss.a
%{_libdir}/libnssutil.a
%{_libdir}/libnssb.a
%{_libdir}/libnssckfw.a
%{_libdir}/libsmime.a
%{_libdir}/libssl.a
%endif


%changelog
* Mon Jul 07 2025 wally <wally> 2:3.113.0-1.1.mga9
+ Revision: 2250643
- drop nowadays unneeded %%pretrans scriptlet (mga#34397)
+ ns80 <ns80>
- new version 3.113 (mga#34393)
- new version 3.112 (mga#34337)
- new version 3.111 (mga#34287)
- new version 3.110
- new version 3.109 (mga#34064)
- new version 3.108 (mga#33983)
- new version 3.107 (mga#33804)
- new version 3.106 (mga#33713)
- new version 3.105
- new version 3.104 (mga#33501)
- new version 3.102
- new version 3.101 (mga#33288)
- new version 3.100 (mga#33211)
- new version 3.99 (mga#32986)
- new version 3.98 (mga#32876)
- new version 3.97 (mga#32762)
- new version 3.96.1 (mga#32642)
- new version 3.95 (mga#32551)
- new version 3.94 (mga#32477)
- new version 3.93 (mga#32207)

* Wed Jul 05 2023 luigiwalser <luigiwalser> 2:3.91.0-1.mga9
+ Revision: 1963609
- remove nss 3.90 build fix patch
- 3.91

* Thu Jun 08 2023 luigiwalser <luigiwalser> 2:3.90.0-1.mga9
+ Revision: 1961349
- add build fix patch from fedora
- 3.90

* Tue May 09 2023 luigiwalser <luigiwalser> 2:3.89.1-1.mga9
+ Revision: 1956345
- 3.89.1

* Thu Mar 16 2023 kekepower <kekepower> 2:3.89.0-2.mga9
+ Revision: 1949472
- Provide nss-tools to allow autofirma to install
  O This package is to authenticate on Spanish government sites and sign documents electronically

* Mon Mar 13 2023 luigiwalser <luigiwalser> 2:3.89.0-1.mga9
+ Revision: 1948821
- 3.89

* Wed Feb 15 2023 luigiwalser <luigiwalser> 2:3.88.1-1.mga9
+ Revision: 1942586
- 3.88.1

* Tue Jan 17 2023 luigiwalser <luigiwalser> 2:3.87.0-1.mga9
+ Revision: 1934024
- 3.87

* Tue Dec 13 2022 luigiwalser <luigiwalser> 2:3.86.0-1.mga9
+ Revision: 1921685
- 3.86

* Tue Nov 15 2022 luigiwalser <luigiwalser> 2:3.85.0-1.mga9
+ Revision: 1907593
- 3.85

* Mon Oct 17 2022 luigiwalser <luigiwalser> 2:3.84.0-1.mga9
+ Revision: 1897276
- 3.84

* Mon Sep 19 2022 luigiwalser <luigiwalser> 2:3.83.0-1.mga9
+ Revision: 1890589
- 3.83

* Tue Aug 23 2022 luigiwalser <luigiwalser> 2:3.82.0-1.mga9
+ Revision: 1879628
- 3.82

* Mon Jul 25 2022 luigiwalser <luigiwalser> 2:3.81.0-1.mga9
+ Revision: 1871550
- 3.81

* Mon Jun 27 2022 luigiwalser <luigiwalser> 2:3.80.0-1.mga9
+ Revision: 1866444
- 3.80

* Tue May 31 2022 luigiwalser <luigiwalser> 2:3.79.0-1.mga9
+ Revision: 1860918
- 3.79

* Tue May 03 2022 luigiwalser <luigiwalser> 2:3.78.0-1.mga9
+ Revision: 1855580
- 3.78

* Tue Apr 05 2022 luigiwalser <luigiwalser> 2:3.77.0-1.mga9
+ Revision: 1845263
- 3.77

* Sat Mar 19 2022 umeabot <umeabot> 2:3.76.0-2.mga9
+ Revision: 1799934
- Mageia 9 Mass Rebuild

* Sat Mar 05 2022 luigiwalser <luigiwalser> 2:3.76.0-1.mga9
+ Revision: 1789115
- 3.76

* Mon Feb 07 2022 luigiwalser <luigiwalser> 2:3.75.0-1.mga9
+ Revision: 1772551
- 3.75

* Tue Jan 11 2022 luigiwalser <luigiwalser> 2:3.74.0-1.mga9
+ Revision: 1767879
- 3.74

* Wed Dec 01 2021 luigiwalser <luigiwalser> 2:3.73.0-1.mga9
+ Revision: 1760482
- 3.73

* Tue Nov 02 2021 luigiwalser <luigiwalser> 2:3.72.0-1.mga9
+ Revision: 1753654
- 3.72

* Mon Oct 04 2021 luigiwalser <luigiwalser> 2:3.71.0-1.mga9
+ Revision: 1749363
- 3.71

* Tue Sep 07 2021 luigiwalser <luigiwalser> 2:3.70.0-1.mga9
+ Revision: 1744403
- 3.70

* Mon Aug 09 2021 luigiwalser <luigiwalser> 2:3.69.0-1.mga9
+ Revision: 1740774
- 3.69

* Mon Jul 12 2021 luigiwalser <luigiwalser> 2:3.68.0-1.mga9
+ Revision: 1735724
- 3.68

* Mon Jun 28 2021 luigiwalser <luigiwalser> 2:3.67.0-1.mga9
+ Revision: 1734096
- 3.67

* Mon May 31 2021 luigiwalser <luigiwalser> 2:3.66.0-1.mga9
+ Revision: 1729040
- 3.66

* Sun Apr 25 2021 neoclust <neoclust> 2:3.64.0-1.mga9
+ Revision: 1719675
- new version 3.64

* Thu Mar 25 2021 ns80 <ns80> 2:3.63.0-1.mga9
+ Revision: 1709844
- new version 3.63 (mga#28641)

* Sat Feb 27 2021 luigiwalser <luigiwalser> 2:3.62.0-1.mga9
+ Revision: 1692495
- 3.62

* Sat Jan 30 2021 luigiwalser <luigiwalser> 2:3.61.0-1.mga8
+ Revision: 1674107
- 3.61

* Thu Jan 07 2021 luigiwalser <luigiwalser> 2:3.60.1-1.mga8
+ Revision: 1669343
- 3.60.1

* Mon Dec 14 2020 luigiwalser <luigiwalser> 2:3.60.0-1.mga8
+ Revision: 1657438
- 3.60

* Mon Nov 16 2020 luigiwalser <luigiwalser> 2:3.59.0-1.mga8
+ Revision: 1646714
- 3.59

* Wed Oct 21 2020 luigiwalser <luigiwalser> 2:3.58.0-1.mga8
+ Revision: 1637844
- 3.58

* Mon Sep 21 2020 luigiwalser <luigiwalser> 2:3.57.0-1.mga8
+ Revision: 1629356
- 3.57
- nss no longer builds in rootcerts since 3.53

* Mon Aug 24 2020 luigiwalser <luigiwalser> 2:3.56.0-1.mga8
+ Revision: 1618702
- 3.56

* Tue Jul 28 2020 luigiwalser <luigiwalser> 2:3.55.0-1.mga8
+ Revision: 1609422
- 3.55
- update scriplet calls to update-crypto-policies per fedora packaging

* Tue Jun 30 2020 luigiwalser <luigiwalser> 2:3.54.0-1.mga8
+ Revision: 1600789
- 3.54

* Thu Jun 18 2020 luigiwalser <luigiwalser> 2:3.53.1-1.mga8
+ Revision: 1596523
- 3.53.1

* Thu Jun 11 2020 ovitters <ovitters> 2:3.53.0-5.mga8
+ Revision: 1592560
- rebuild for new rootcerts
+ tv <tv>
- kill dead commands that were already obsolete by the time of the mdv->mga import

* Thu Jun 04 2020 luigiwalser <luigiwalser> 2:3.53.0-4.mga8
+ Revision: 1590437
- add crypto policy for nss loading p11-kit (from fedora)

* Thu Jun 04 2020 luigiwalser <luigiwalser> 2:3.53.0-3.mga8
+ Revision: 1590419
- add patch from fedora to delay new CK_GCM_PARAMS semantics unless explicitly enabled

* Wed Jun 03 2020 luigiwalser <luigiwalser> 2:3.53.0-2.mga8
+ Revision: 1590118
- explicitly link libnssckbi.so to p11-kit-trust.so
- nss lib now requires p11-kit-trust to replace dropped libnssckbi.so

* Wed Jun 03 2020 luigiwalser <luigiwalser> 2:3.53.0-1.mga8
+ Revision: 1590110
- libnssckbi.so is no longer built
- rediff patch 5
- 3.53

* Tue May 05 2020 luigiwalser <luigiwalser> 2:3.52.0-2.mga8
+ Revision: 1580659
- BR latest rootcerts
- try without netscape-is-nss patch
- add patch to hopefully fix build with system rootcerts

* Tue May 05 2020 tv <tv> 2:3.52.0-1.mga8
+ Revision: 1580258
- disable nss-use_system_rootcerts.patch in order to build successfully
+ luigiwalser <luigiwalser>
- 3.52

* Fri Apr 17 2020 tv <tv> 2:3.51.1-2.mga8
+ Revision: 1568391
- better/simpler heuristic for USE_64
- drop verisign certficate that is obsolete since 2015...
- remove unused decade old brazilian certificate

* Fri Apr 10 2020 tv <tv> 2:3.51.1-1.mga8
+ Revision: 1566209
- 3.51.1
+ danf <danf>
- Switch URLs from http: to https:

* Tue Mar 10 2020 luigiwalser <luigiwalser> 2:3.51.0-1.mga8
+ Revision: 1555289
- 3.51

* Fri Feb 21 2020 umeabot <umeabot> 2:3.50.0-2.mga8
+ Revision: 1548115
- Mageia 8 Mass Rebuild

* Tue Feb 11 2020 luigiwalser <luigiwalser> 2:3.50.0-1.mga8
+ Revision: 1488832
- 3.50

* Fri Jan 24 2020 ns80 <ns80> 2:3.49.2-1.mga8
+ Revision: 1482630
- new version 3.49.2

* Thu Jan 23 2020 ns80 <ns80> 2:3.49.1-2.mga8
+ Revision: 1482452
- add patch from fedora to fix armv7hl build

* Thu Jan 23 2020 ns80 <ns80> 2:3.49.1-1.mga8
+ Revision: 1482355
- new version 3.49.1

* Wed Jan 08 2020 tv <tv> 2:3.49.0-1.mga8
+ Revision: 1477260
- 3.49
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Fri Dec 06 2019 tv <tv> 2:3.48.0-1.mga8
+ Revision: 1464811
- 3.48.0

* Sat Nov 30 2019 luigiwalser <luigiwalser> 2:3.47.1-2.mga8
+ Revision: 1463832
- rebuild for rootcerts

* Sat Nov 23 2019 tv <tv> 2:3.47.1-1.mga8
+ Revision: 1462480
- 3.47.1

* Tue Oct 22 2019 luigiwalser <luigiwalser> 2:3.47.0-1.mga8
+ Revision: 1455169
- 3.47

* Tue Sep 03 2019 luigiwalser <luigiwalser> 2:3.46.0-1.mga8
+ Revision: 1436511
- 3.46

* Mon Aug 26 2019 luigiwalser <luigiwalser> 2:3.45-3.mga8
+ Revision: 1432380
- rebuild for rootcerts

* Thu Jul 11 2019 luigiwalser <luigiwalser> 2:3.45-2.mga8
+ Revision: 1420092
- rebuild for rootcerts

* Tue Jul 09 2019 tv <tv> 2:3.45-1.mga8
+ Revision: 1419726
- 3.45

* Sat Jun 29 2019 tv <tv> 2:3.44.1-1.mga8
+ Revision: 1416120
- 3.44.1

* Thu May 23 2019 luigiwalser <luigiwalser> 2:3.44.0-1.mga7
+ Revision: 1398952
- 3.44

* Tue Mar 19 2019 luigiwalser <luigiwalser> 2:3.43.0-1.mga7
+ Revision: 1378831
- 3.43

* Thu Feb 14 2019 luigiwalser <luigiwalser> 2:3.42.1-1.mga7
+ Revision: 1367098
- 3.42.1

* Mon Jan 28 2019 tv <tv> 2:3.42.0-1.mga7
+ Revision: 1361774
- 3.42

* Sat Dec 08 2018 luigiwalser <luigiwalser> 2:3.41.0-1.mga7
+ Revision: 1338994
- 3.41

* Tue Oct 30 2018 tv <tv> 2:3.40.0-1.mga7
+ Revision: 1326603
- 3.40

* Tue Oct 16 2018 luigiwalser <luigiwalser> 2:3.39.0-1.mga7
+ Revision: 1320668
- 3.39

* Sun Sep 23 2018 umeabot <umeabot> 2:3.38.0-2.mga7
+ Revision: 1299801
- Mageia 7 Mass Rebuild

* Fri Jun 22 2018 luigiwalser <luigiwalser> 2:3.38.0-1.mga7
+ Revision: 1239097
- 3.38

* Fri Jun 08 2018 luigiwalser <luigiwalser> 2:3.37.3-1.mga7
+ Revision: 1235264
- 3.37.3

* Sun May 27 2018 tv <tv> 2:3.37.1-2.mga7
+ Revision: 1232453
- 3.37.1

* Sat May 12 2018 luigiwalser <luigiwalser> 2:3.37.0-2.mga7
+ Revision: 1228672
- rebuild for rootcerts

* Wed May 09 2018 luigiwalser <luigiwalser> 2:3.37.0-1.mga7
+ Revision: 1227889
- fix package version

* Wed May 09 2018 tv <tv> 2:3.37-1.mga7
+ Revision: 1227849
- 3.37

* Wed Apr 11 2018 tv <tv> 2:3.36.1-1.mga7
+ Revision: 1217641
- fix applying patch
- 3.36.1

* Thu Mar 15 2018 luigiwalser <luigiwalser> 2:3.36.0-1.mga7
+ Revision: 1209733
- certcgi is no more
- 3.36 (requires nspr 4.19)
- rediff patch 4
- remove upstream patch 6
+ wally <wally>
- fix devel pkg provides on aarch64
- add patch from usptream to fix build on aarch64

* Sat Jan 20 2018 luigiwalser <luigiwalser> 2:3.35.0-1.mga7
+ Revision: 1195149
- 3.35

* Mon Dec 11 2017 tv <tv> 2:3.34.1-1.mga7
+ Revision: 1182192
- fix filelist
- new release

* Tue Nov 14 2017 luigiwalser <luigiwalser> 2:3.33.0-3.mga7
+ Revision: 1177333
- rebuild for rootcerts

* Sat Oct 28 2017 tv <tv> 2:3.33.0-2.mga7
+ Revision: 1174342
- adjust filelist
- new release

* Fri Sep 29 2017 luigiwalser <luigiwalser> 2:3.28.6-1.mga7
+ Revision: 1161799
- add upstream patch to fix build
- 3.28.6

* Wed Aug 09 2017 luigiwalser <luigiwalser> 2:3.28.5-2.mga7
+ Revision: 1139132
- rebuild for rootcerts

* Tue May 30 2017 luigiwalser <luigiwalser> 2:3.28.5-1.mga6
+ Revision: 1105579
- 3.28.5
- add upstream patch to fix CVE-2017-7502

* Thu Apr 20 2017 luigiwalser <luigiwalser> 2:3.28.4-1.mga6
+ Revision: 1096894
- 3.28.4

* Wed Mar 08 2017 mrambo3501 <mrambo3501> 2:3.28.3-6.mga6
+ Revision: 1090215
- rebuild for new rootcerts
+ akien <akien>
- Rebuild for rootcerts-20170209.00-1.mga6

* Tue Mar 07 2017 mrambo3501 <mrambo3501> 2:3.28.3-1.mga6
+ Revision: 1089464
- update to version 3.28.3 (required for firefox 52)
- added patch to use system root certificates (bug 20053)

* Thu Dec 01 2016 luigiwalser <luigiwalser> 2:3.27.2-1.mga6
+ Revision: 1071437
- 3.27.2

* Wed Oct 05 2016 luigiwalser <luigiwalser> 2:3.27.1-1.mga6
+ Revision: 1058833
- rediff patch1

* Tue Sep 20 2016 luigiwalser <luigiwalser> 2:3.26.0-2.mga6
+ Revision: 1054694
- rebuild for rootcerts

* Fri Aug 05 2016 luigiwalser <luigiwalser> 2:3.26.0-1.mga6
+ Revision: 1044672
- 3.26

* Mon Jul 25 2016 luigiwalser <luigiwalser> 2:3.25.0-1.mga6
+ Revision: 1043621
- 3.25

* Wed Jun 08 2016 tmb <tmb> 2:3.24.0-3.mga6
+ Revision: 1020884
- submit to release

* Wed Jun 08 2016 luigiwalser <luigiwalser> 2:3.24.0-2.mga6
+ Revision: 1020734
- install new libfreeblpriv3 library

* Tue Jun 07 2016 luigiwalser <luigiwalser> 2:3.24.0-1.mga6
+ Revision: 1020587
- 3.24

* Sat Mar 12 2016 tv <tv> 2:3.23.0-1.mga6
+ Revision: 989580
- adjust file list
- rediff patch
- fix build when no subversion
- there's no subversion
- 3.23
+ luigiwalser <luigiwalser>
- fix incorrect changes to spec

* Sat Mar 12 2016 tv <tv> 2:3.22.2-1.mga6
+ Revision: 989539
- adjust file list
- adjust file list
- 3.22.2

* Fri Feb 26 2016 tv <tv> 2:3.21.1-1.mga6
+ Revision: 979562
- 3.21.1
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Nov 26 2015 luigiwalser <luigiwalser> 2:3.21.0-1.mga6
+ Revision: 906283
- 3.21

* Sun Nov 01 2015 luigiwalser <luigiwalser> 2:3.20.1-1.mga6
+ Revision: 897240
- 3.20.1

* Fri Aug 28 2015 luigiwalser <luigiwalser> 2:3.20.0-1.mga6
+ Revision: 870699
- 3.20

* Fri Aug 21 2015 tmb <tmb> 2:3.19.3-2.mga6
+ Revision: 867654
- rebuild for new gcc

* Sat Aug 08 2015 luigiwalser <luigiwalser> 2:3.19.3-1.mga6
+ Revision: 861668
- 3.19.3

* Sat Jun 27 2015 luigiwalser <luigiwalser> 2:3.19.2-1.mga6
+ Revision: 846460
- 3.19.2

* Tue Jun 02 2015 luigiwalser <luigiwalser> 2:3.19.1-1.mga5
+ Revision: 822856
- 3.19.1

* Thu May 07 2015 luigiwalser <luigiwalser> 2:3.19.0-1.mga5
+ Revision: 821409
- 3.19

* Wed May 06 2015 luigiwalser <luigiwalser> 2:3.18.1-1.mga5
+ Revision: 821340
- 3.18.1

* Wed Apr 01 2015 luigiwalser <luigiwalser> 2:3.18.0-2.mga5
+ Revision: 819493
- rebuild for updated rootcerts

* Mon Mar 23 2015 luigiwalser <luigiwalser> 2:3.18.0-1.mga5
+ Revision: 819111
- 3.18

* Sat Jan 31 2015 luigiwalser <luigiwalser> 2:3.17.4-2.mga5
+ Revision: 812901
- rebuild for release

* Sat Jan 31 2015 tv <tv> 2:3.17.4-1.mga5
+ Revision: 812846
- 3.17.4

* Mon Dec 08 2014 guillomovitch <guillomovitch> 2:3.17.3-3.mga5
+ Revision: 802203
- add executable man pages

* Tue Dec 02 2014 ennael <ennael> 2:3.17.3-2.mga5
+ Revision: 800342
- rebuild for new rootcerts

* Tue Dec 02 2014 luigiwalser <luigiwalser> 2:3.17.3-1.mga5
+ Revision: 800263
- 3.17.3

* Wed Oct 15 2014 umeabot <umeabot> 2:3.17.2-2.mga5
+ Revision: 751075
- Second Mageia 5 Mass Rebuild

* Tue Oct 14 2014 luigiwalser <luigiwalser> 2:3.17.2-1.mga5
+ Revision: 738648
- 3.17.2

* Fri Sep 26 2014 tmb <tmb> 2:3.17.1-2.mga5
+ Revision: 724797
- bump rel to keep upgrade path

* Wed Sep 24 2014 luigiwalser <luigiwalser> 2:3.17.1-1.mga5
+ Revision: 724004
- 3.17.1

* Tue Sep 16 2014 umeabot <umeabot> 2:3.17.0-3.mga5
+ Revision: 682940
- Mageia 5 Mass Rebuild

* Tue Sep 02 2014 luigiwalser <luigiwalser> 2:3.17.0-2.mga5
+ Revision: 671130
- remove patch 5

* Wed Aug 20 2014 luigiwalser <luigiwalser> 2:3.17.0-1.mga5
+ Revision: 665780
- 3.17
- rediff patch 5
- do not apply patch 5 as it should not be needed anymore

* Sun Aug 17 2014 luigiwalser <luigiwalser> 2:3.16.4-1.mga5
+ Revision: 664503
- 3.16.4

* Fri Jul 11 2014 luigiwalser <luigiwalser> 2:3.16.3-1.mga5
+ Revision: 651206
- 3.16.3

* Wed Jul 02 2014 tv <tv> 2:3.16.2-1.mga5
+ Revision: 642226
- rediff patch 5
- 3.16.2

* Sun Jun 22 2014 tmb <tmb> 2:3.16.1-2.mga5
+ Revision: 638641
- revert 3.16.1 'Imposed name constraints on the French government root
  CA ANSSI (DCISS)' as the CA signs more than gouv.fr domains (mga#13563)

* Thu May 08 2014 oden <oden> 2:3.16.1-1.mga5
+ Revision: 621139
- 3.16.1

* Wed Mar 19 2014 luigiwalser <luigiwalser> 2:3.16.0-1.mga5
+ Revision: 605639
- 3.16

* Wed Mar 19 2014 oden <oden> 2:3.15.5-2.mga5
+ Revision: 605591
- rebuilt to pickup changes in rootcerts-20140318.00
- fix correct build deps

* Wed Feb 26 2014 luigiwalser <luigiwalser> 2:3.15.5-1.mga5
+ Revision: 597343
- 3.15.5

* Fri Jan 17 2014 luigiwalser <luigiwalser> 2:3.15.4-1.mga4
+ Revision: 566768
- 3.15.4

* Tue Dec 10 2013 luigiwalser <luigiwalser> 2:3.15.3.1-1.mga4
+ Revision: 556208
- 3.15.3.1

* Fri Nov 15 2013 luigiwalser <luigiwalser> 2:3.15.3-1.mga4
+ Revision: 551463
- 3.15.3

* Mon Oct 21 2013 umeabot <umeabot> 2:3.15.2-3.mga4
+ Revision: 539099
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 oden <oden> 2:3.15.2-2.mga4
+ Revision: 491363
- rebuilt to pickup the changes as of rootcerts-20130411.00

* Sat Sep 28 2013 luigiwalser <luigiwalser> 2:3.15.2-1.mga4
+ Revision: 488419
- 3.15.2

* Thu Jul 04 2013 luigiwalser <luigiwalser> 2:3.15.1-1.mga4
+ Revision: 450026
- 3.15.1

* Thu Jun 27 2013 fwang <fwang> 2:3.15.0-1.mga4
+ Revision: 447365
- finally fix simplified nss version

* Wed Jun 26 2013 oden <oden> 2:3.15-1.mga4
+ Revision: 446836
- 3.15
- adjust the patches

* Wed Feb 20 2013 luigiwalser <luigiwalser> 2:3.14.3-1.mga3
+ Revision: 399487
- 3.14.3

* Wed Feb 06 2013 luigiwalser <luigiwalser> 2:3.14.2-1.mga3
+ Revision: 394929
- 3.14.2

* Sat Jan 12 2013 umeabot <umeabot> 2:3.14.1-3.mga3
+ Revision: 361061
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 oden <oden> 2:3.14.1-2.mga3
+ Revision: 343292
- rebuilt to pickup the CVE-2013-0743 fix

* Sat Dec 22 2012 luigiwalser <luigiwalser> 2:3.14.1-1.mga3
+ Revision: 334055
- 3.14.1

* Wed Nov 21 2012 luigiwalser <luigiwalser> 2:3.14-3.mga3
+ Revision: 319957
- revert previous change

* Wed Nov 21 2012 fwang <fwang> 2:3.14-2.mga3
+ Revision: 319939
- fix patch version

* Sat Oct 27 2012 luigiwalser <luigiwalser> 2:3.14-1.mga3
+ Revision: 310831
- 3.14
- remove patch 3 (applied upstream)
- rediff patch 0
- fix nss-config for when there is no patch version

* Sun Oct 14 2012 ennael <ennael> 2:3.13.6-2.mga3
+ Revision: 305461
- Documentation group

* Sun Aug 26 2012 luigiwalser <luigiwalser> 2:3.13.6-1.mga3
+ Revision: 284176
- 3.13.6

* Tue Jul 24 2012 fwang <fwang> 2:3.13.5-3.mga3
+ Revision: 274023
- add conflicts to ease upgrading

* Sat Jul 21 2012 colin <colin> 2:3.13.5-2.mga3
+ Revision: 273158
- Update for usrmove

* Tue Jun 05 2012 luigiwalser <luigiwalser> 2:3.13.5-1.mga3
+ Revision: 255992
- 3.13.5

* Sun Apr 15 2012 luigiwalser <luigiwalser> 2:3.13.4-1.mga2
+ Revision: 230967
- 3.13.4
+ dmorgan <dmorgan>
- Fix the requires

* Sun Feb 26 2012 dmorgan <dmorgan> 2:3.13.3-3.mga2
+ Revision: 215094
+ rebuild (emptylog)

* Sun Feb 26 2012 luigiwalser <luigiwalser> 2:3.13.3-2.mga2
+ Revision: 215062
- revert temporary fix and rebuild against nspr
- escape commented percent signs
- temporary fix for nspr 4.9 issue

* Sun Feb 26 2012 luigiwalser <luigiwalser> 2:3.13.3-1.mga2
+ Revision: 215046
- parallel make does not work right now
- 3.13.3

* Sat Nov 12 2011 fwang <fwang> 2:3.13.1-2.mga2
+ Revision: 166887
- Fix __GNUC_MINOR mistype that caused users of NSS to fail to build

* Thu Nov 10 2011 fwang <fwang> 2:3.13.1-1.mga2
+ Revision: 166151
- new version 3.13.1
- drop merged patch

* Wed Sep 28 2011 ovitters <ovitters> 2:3.12.11-4.mga2
+ Revision: 149923
- fix typo in header file nss-3.12.11-new_certdata.txt_format.diff patch

* Thu Sep 01 2011 dmorgan <dmorgan> 2:3.12.11-3.mga2
+ Revision: 137444
- Apply P5
- Add P5: Fix build
+ fwang <fwang>
- rebuild for higher release tag than stable 1
- new version 3.12.9

* Sun May 22 2011 blino <blino> 2:3.12.9-2.mga1
+ Revision: 100168
- split doc in a sub-package (about 1MB uncompressed)

* Sat Jan 29 2011 dmorgan <dmorgan> 2:3.12.9-1.mga1
+ Revision: 43420
- New version 3.12.9

* Sat Jan 15 2011 blino <blino> 2:3.12.8-3.mga1
+ Revision: 19081
- remove old ldconfig scriptlets, version checks, and conditionnals
- imported package nss


* Sat Dec 25 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.8-3mdv2011.0
+ Revision: 625024
- rebuilt to pickup rootcerts-20101202 changes
- fix #61964 (nss should depend of the latest version of nspr)

* Thu Nov 25 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.8-2mdv2011.0
+ Revision: 601067
- rebuilt to pickup the changes in rootcerts-20101119.00

* Tue Oct 12 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.8-1mdv2011.0
+ Revision: 585167
- 3.12.8
- rediffed one patch
- dropped bsolete patches

* Tue Oct 12 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.7-3mdv2011.0
+ Revision: 585103
- require the version, or later of the nspr libs nss was built against. fixes #61249

* Thu Sep 09 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.7-2mdv2011.0
+ Revision: 576968
- fix backporting to older products
- rebuilt against new rootcerts-20100827

* Sat Aug 21 2010 Funda Wang <fwang@mandriva.org> 2:3.12.7-1mdv2011.0
+ Revision: 571721
- New version 3.12.7

* Mon May 17 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.6-6mdv2010.1
+ Revision: 545022
- fix deps
- rebuilt against rootcerts-20100408.00

* Tue Apr 27 2010 Christophe Fergeau <cfergeau@mandriva.com> 2:3.12.6-5mdv2010.1
+ Revision: 539590
- rebuild so that shared libraries are properly stripped again

* Wed Apr 21 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.6-4mdv2010.1
+ Revision: 537675
- dacapo, but for the nss library

* Wed Apr 21 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.6-3mdv2010.1
+ Revision: 537664
- require the exact version of sqlite3 it was built against or a later version

* Tue Apr 13 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.6-2mdv2010.1
+ Revision: 534197
- added backporting magic for updates
- adjust deps

* Thu Apr 01 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.6-1mdv2010.1
+ Revision: 530645
- 3.12.6 (official release)

* Tue Mar 23 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.6-0.0.1mdv2010.1
+ Revision: 526884
- use a cvs snap (NSS_3_12_6_RTM)
- rediffed the sqlite patch
- added two patches from fedora

* Fri Mar 12 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.5-4mdv2010.1
+ Revision: 518394
- rebuilt to pickup changes from rootcerts-20100216.01

* Wed Feb 03 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.5-3mdv2010.1
+ Revision: 500472
- rebuilt to pickup fixes in rootcerts-20091203.04

* Sun Jan 24 2010 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.5-2mdv2010.1
+ Revision: 495471
- rebuilt against rootcerts-20091203.00

* Wed Dec 16 2009 Funda Wang <fwang@mandriva.org> 2:3.12.5-1mdv2010.1
+ Revision: 479151
- fix file list
- new version 3.12.5

* Mon Oct 19 2009 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.4-2mdv2010.0
+ Revision: 458252
- rebuilt to pickup changes from rootcerts-20090831.00-1mdv2010.0

* Mon Aug 31 2009 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.4-1mdv2010.0
+ Revision: 422988
- 3.12.4
- nuke one *.orig file

* Tue Aug 04 2009 Oden Eriksson <oeriksson@mandriva.com> 2:3.12.3.1-1mdv2010.0
+ Revision: 408938
- 3.12.3.1

* Sat May 30 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2:3.12.3-2mdv2010.0
+ Revision: 381501
- fix file list one more time

* Sat May 30 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2:3.12.3-1mdv2010.0
+ Revision: 381500
- update to new version 3.12.3
  rediff patch 4 and 5
- drop patch 6, fixed upstream
- fix file list

* Mon Mar 23 2009 Oden Eriksson <oeriksson@mandriva.com> 2:3.12-12mdv2009.1
+ Revision: 360727
- rebuilt to pickup new data from the rootcerts (20090115.00) package

* Sun Jan 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2:3.12-11mdv2009.1
+ Revision: 333523
- bump..
- increase size for string allocated by one to make room for string terminator
  (P6, fixes /usr/bin/addbuiltin SIGABRT with 'free(): invalid pointer')

* Sun Jan 25 2009 Oden Eriksson <oeriksson@mandriva.com> 2:3.12-10mdv2009.1
+ Revision: 333463
- rebuilt with a better patch for fixing -Werror=format-security (P5)
- fix broken patch

* Mon Dec 22 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2:3.12-9mdv2009.1
+ Revision: 317711
- build with %%setup_compile_flags macro
- Patch5: fix building with -Werror=format-security
- spec file clean

* Mon Dec 08 2008 Funda Wang <fwang@mandriva.org> 2:3.12-8mdv2009.1
+ Revision: 311850
- use fedora package layout (put actual .so at /lib, and devel symbolic link at /usr/lib)

* Thu Oct 23 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2:3.12-7mdv2009.1
+ Revision: 296799
- remove undocumented and unexplainable conflict with perl-PAR

  + Oden Eriksson <oeriksson@mandriva.com>
    - added ugly provides due to ugly nss libnames and sonames

* Sun Aug 10 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2:3.12-5mdv2009.0
+ Revision: 270259
- fix mixture of tabs and spaces
- bump release tag
- package libnssdbm3.so, hopefully this will fix bug #42603
- export few options for nss build

  + Frederik Himpe <fhimpe@mandriva.org>
    - Fix license
    - Remove nss-clobber.sh and noexecstack patch, both are
      not necessary anymore according to RH

* Sat Aug 09 2008 Tiago Salem <salem@mandriva.com.br> 2:3.12-4mdv2009.0
+ Revision: 269769
- add -lnssutil3 to nss-config.in
- bump release

* Fri Aug 08 2008 Tiago Salem <salem@mandriva.com.br> 2:3.12-3mdv2009.0
+ Revision: 269661
- add missing -lnssutil3 to nss.pc (breaks thunderbird build)
- bump release

* Thu Aug 07 2008 Funda Wang <fwang@mandriva.org> 2:3.12-2mdv2009.0
+ Revision: 266297
- bump release
- use system sqlite3
- add nssutil.so

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - package libnssutil3.so also

* Thu Aug 07 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2:3.12-1mdv2009.0
+ Revision: 265867
- update to new version 3.12
- drop patch1, fixed upstream
- fix file list
- spec file clean

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 2:3.11.9-3mdv2009.0
+ Revision: 223350
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu Feb 14 2008 Oden Eriksson <oeriksson@mandriva.com> 2:3.11.9-2mdv2008.1
+ Revision: 168377
- rebuilt to pickup new root ca's in rootcerts-20080117.00

* Thu Feb 14 2008 Marcelo Ricardo Leitner <mrl@mandriva.com> 2:3.11.9-1mdv2008.1
+ Revision: 167772
- New upstream: 3.11.9

* Thu Feb 07 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 2:3.11.7-4mdv2008.1
+ Revision: 163760
- really fix incorrect major
- bump back release a bit since neither of previous ones went through :)
- bah! nss.pc should be working properly now! %%&#?\194?\164%%#
- grf, fix nspr version require and, libdir path and include path
- fix nss.pc so we don't ship an old, static one..

* Thu Dec 20 2007 Oden Eriksson <oeriksson@mandriva.com> 2:3.11.7-3mdv2008.1
+ Revision: 135405
- use the correct syntax for the rootcerts build dependency
- rebuilt to pickup latest rootcerts (hardcoded into the %%{_libdir}/libnssckbi.so library)

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Jul 20 2007 Funda Wang <fwang@mandriva.org> 2:3.11.7-2mdv2008.0
+ Revision: 53912
- fix static devel requires

* Fri Jul 20 2007 Funda Wang <fwang@mandriva.org> 2:3.11.7-1mdv2008.0
+ Revision: 53885
- fix file list
- New version

* Sun Jun 24 2007 David Walluck <walluck@mandriva.org> 2:3.11.5-5mdv2008.0
+ Revision: 43748
- add patch for certdata.txt
- spec cleanup


* Wed Mar 21 2007 Andreas Hasenack <andreas@mandriva.com> 3.11.5-4mdv2007.1
+ Revision: 147547
- fix library path
- add back Brazilian Gov. certificate
- add new Verisign certificate (#29612)

* Fri Mar 09 2007 David Walluck <walluck@mandriva.org> 2:3.11.5-4mdv2007.1
+ Revision: 139555
- fix description

* Fri Mar 09 2007 David Walluck <walluck@mandriva.org> 2:3.11.5-3mdv2007.1
+ Revision: 138691
- add docs to file list (accidently removed)

* Fri Mar 09 2007 David Walluck <walluck@mandriva.org> 2:3.11.5-2mdv2007.1
+ Revision: 138688
- really enable lib
  static-devel package conflicts with libopenssl-static-devel
  use find and xargs to remove CVS directories
  use cp -a everywhere
  macros
  mark nss-config as multiarch
  fix duplicate nss-config in file list
  run shlibsign in libnss %%post (requires nss)
  use explicit file list

* Fri Mar 09 2007 David Walluck <walluck@mandriva.org> 2:3.11.5-1mdv2007.1
+ Revision: 138582
- 3.11.5

* Tue Mar 06 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 2:3.11.4-8mdv2007.1
+ Revision: 133767
- Fix lib versions on nss-config

* Tue Mar 06 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 2:3.11.4-7mdv2007.1
+ Revision: 133671
- Add support to /usr/bin/nss-config (based on Fedora's one)

* Sun Mar 04 2007 David Walluck <walluck@mandriva.org> 2:3.11.4-6mdv2007.1
+ Revision: 132567
- rebuild

* Wed Feb 21 2007 Götz Waschk <waschk@mandriva.org> 2:3.11.4-5mdv2007.1
+ Revision: 123208
- rebuild

  + Oden Eriksson <oeriksson@mandriva.com>
    - fix deps

* Fri Feb 09 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 2:3.11.4-3mdv2007.1
+ Revision: 118491
- Added pkcs11 devel files to libnss3-devel package.

* Thu Feb 08 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 2:3.11.4-2mdv2007.1
+ Revision: 118137
- Bump epoch, so we upgrade cleanly old firefox's libnss3.
- Do not enforce (wrong) nspr version.
- Removed patch nss-system-nspr: prefer doing it via env. variables.
- Tagged as license LGPL too
- Enabled the library.
- Do not use chrpath: it is not needed, and we are using this library now.
- Fixed epoch stuff on library packages.
- Added ldconfig call to library package.

* Sat Dec 16 2006 David Walluck <walluck@mandriva.org> 1:3.11.4-1mdv2007.1
+ Revision: 98079
- 3.11.4
- Import nss

* Fri Apr 28 2006 Oden Eriksson <oeriksson@mandriva.com> 1:3.11-1mdk
- drop redundant patches; P0,P4
- drop upstream patches; P2,P3,P85
- added P50,P51 from fedora

* Fri Nov 11 2005 Oden Eriksson <oeriksson@mandriva.com> 1:3.9.2-1mdk
- rolled back to match mozilla-firefox libs
- added some patches from the mozilla-firefox package
- added P4 to teach it ~/.mozilla

* Sat Nov 05 2005 Nicolas Lécureuil <neoclust@mandriva.org> 3.10.2-3mdk
- Fix BuildRequires

* Fri Nov 04 2005 Nicolas Lécureuil <neoclust@mandriva.org> 3.10.2-2mdk
- Fix BuildRequires

* Wed Nov 02 2005 David Walluck <walluck@mandrake.org> 0:3.10.2-1mdk
- 3.10.2

* Fri Jan 28 2005 David Walluck <walluck@mandrake.org> 3.9.2-1mdk
- release

